encode_custom_to_arrow

Function encode_custom_to_arrow 

pub fn encode_custom_to_arrow(
    type_name: &str,
    items: &[Arc<dyn CustomDataTrait>],
) -> Result<Option<RecordBatch>, Error>
Encodes a slice of custom data trait objects to a RecordBatch using the registered encoder.

Errors

Returns an error if the type is not registered or encoding fails.