ensure_arrow_registered

Function ensure_arrow_registered 

pub fn ensure_arrow_registered(
    type_name: &str,
    schema: Arc<Schema>,
    encoder: ArrowEncoder,
    decoder: ArrowDecoder,
) -> Result<(), Error>
Registers Arrow schema, encoder, and decoder for the given custom data type name if not already registered. If the type is already registered, returns Ok(()) without overwriting (idempotent). Use this where repeated registration can occur (e.g. module init).

Errors

Does not return an error (idempotent insert into DashMap).