pub fn get_rust_extractor(type_name: &str) -> Option<PyExtractor>Expand description
Calls the registered factory for the given type name and returns the extractor, if any.
pub fn get_rust_extractor(type_name: &str) -> Option<PyExtractor>Calls the registered factory for the given type name and returns the extractor, if any.