pub fn register_json_deserializer(
type_name: &str,
deserializer: JsonDeserializer,
) -> Result<(), Error>Expand description
Registers a JSON deserializer for the given custom data type name.
When Data::deserialize sees this type name, it will call this function.
Errors
Returns an error if the type is already registered.